import { TTLParser } from "@sveltekit-statefull-session/core";
export class RedisSessionRepository {
    redisPrefix = 'session-key';
    #redisClient;
    #ttl;
    name = 'redis';
    constructor(options) {
        this.#ttl = new TTLParser(options.ttl);
        this.#redisClient = options.client;
    }
    getRedisKey(sessionKey) {
        return `${this.redisPrefix}:${sessionKey}`;
    }
    async checkConnectivity() {
        if (!this.#redisClient.isOpen) {
            await this.#redisClient.connect();
        }
    }
    async exists(sessionKey) {
        await this.checkConnectivity();
        const value = await this.#redisClient.get(this.getRedisKey(sessionKey));
        return value !== null;
    }
    async initializeSession(sessionKey) {
        await this.checkConnectivity();
        await this.#redisClient.set(this.getRedisKey(sessionKey), JSON.stringify('null'), {
            EX: this.#ttl.toSecond()
        });
    }
    async loadValue(sessionKey) {
        await this.checkConnectivity();
        const value = await this.#redisClient.get(this.getRedisKey(sessionKey));
        if (!value) {
            return null;
        }
        return JSON.parse(value);
    }
    async storeValue(sessionKey, value) {
        await this.checkConnectivity();
        await this.#redisClient.set(this.getRedisKey(sessionKey), JSON.stringify(value), {
            EX: this.#ttl.toSecond()
        });
    }
    async destroySession(sessionKey) {
        await this.checkConnectivity();
        await this.#redisClient.del(this.getRedisKey(sessionKey));
    }
    async purgeExpired() {
    }
    ttl() {
        return this.#ttl;
    }
}
